Package 'chronometre'

Title: A 'chronomètre' is a 'stopwatch'
Description: As a 'chronomètre' is a 'stopwatch', this package offers a simple stopwatch, and in particular one that can be shared with Python (using the corresponding package of the same name available via 'PyPi') such that both interpreters operate on the same object instance and shown in the demo file, as well as in the unit tests.
Authors: Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>)
Maintainer: Dirk Eddelbuettel <[email protected]>
License: GPL (>= 2)
Version: 0.0.2
Built: 2026-06-05 07:19:30 UTC
Source: https://github.com/eddelbuettel/chronometre-r

Help Index


A 'chronomètre' is a 'stopwatch'

Description

As a 'chronomètre' is a 'stopwatch', this package offers a simple stopwatch, and in particular one that can be shared with Python (using the corresponding package of the same name available via 'PyPi') such that both interpreters operate on the same object instance and shown in the demo file, as well as in the unit tests.

Package Content

Index of help topics:

chronometre-package     A 'chronomètre' is a 'stopwatch'

Maintainer

Dirk Eddelbuettel <[email protected]>

Author(s)

Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>)