Welcome to ClientVPS Mirrors

Help for package chronometre
Type: Package
Title: A 'chronomètre' is a 'stopwatch'
Version: 0.0.2
Date: 2026-02-05
Description: As a 'chronomètre' is a 'stopwatch', this package offers a simple stopwatch, and in particular one that can be shared with Python (using the corresponding package of the same name available via 'PyPi') such that both interpreters operate on the same object instance and shown in the demo file, as well as in the unit tests.
Suggests: RcppSpdlog, xptr, reticulate, tinytest
URL: https://github.com/eddelbuettel/chronometre-r
BugReports: https://github.com/eddelbuettel/chronometre-r/issues
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-02-05 12:56:47 UTC; edd
Author: Dirk Eddelbuettel ORCID iD [aut, cre]
Maintainer: Dirk Eddelbuettel <edd@debian.org>
Repository: CRAN
Date/Publication: 2026-02-05 13:30:02 UTC

A 'chronomètre' is a 'stopwatch'

Description

As a 'chronomètre' is a 'stopwatch', this package offers a simple stopwatch, and in particular one that can be shared with Python (using the corresponding package of the same name available via 'PyPi') such that both interpreters operate on the same object instance and shown in the demo file, as well as in the unit tests.

Package Content

Index of help topics:

chronometre-package     A 'chronomètre' is a 'stopwatch'

Maintainer

Dirk Eddelbuettel <edd@debian.org>

Author(s)

Dirk Eddelbuettel [aut, cre] (ORCID: <https://orcid.org/0000-0001-6419-907X>)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.